import * as react from 'react';
import { UseQueryOptions, UseQueryResult } from '@tanstack/react-query';

type ServiceMethod<I, O> = (req: I, initReq: RequestInitWithPathPrefix) => Promise<O>;
interface RequestInitWithPathPrefix extends RequestInit {
    pathPrefix?: string;
}
type ServiceError = Error | ErrorResponse;
type OnErrorHandler<O> = (error: Error | ErrorResponse) => O | null;
interface ErrorResponse {
    codeName?: string;
    code: number;
    message: string;
    details: unknown[];
}
type UseServiceQueryOptions<M extends ServiceMethod<Parameters<M>[0], ReturnType<M>>> = Omit<UseQueryOptions<Awaited<ReturnType<M>>, ServiceError>, 'queryFn'> & {
    onError?: OnErrorHandler<ReturnType<M>>;
};
type UseServiceQueryResult<O> = UseQueryResult<Awaited<O>, ServiceError>;
declare function useServiceQuery<M extends ServiceMethod<Parameters<M>[0], Awaited<ReturnType<M>>>>(method: M, req: Parameters<M>[0], options?: UseServiceQueryOptions<M>): UseServiceQueryResult<ReturnType<M>>;
declare const ServiceContext: react.Context<RequestInitWithPathPrefix>;
declare function isErrorResponse(error: Error | ErrorResponse): error is ErrorResponse;

export { type ErrorResponse, type OnErrorHandler, type RequestInitWithPathPrefix, ServiceContext, type ServiceError, type ServiceMethod, isErrorResponse, useServiceQuery };
